@@ -23,10 +23,12 @@
     See the License for the specific language governing permissions and
     limitations under the License.
 """
+import os
 import sys
 import time
 import logging
 import argparse
+import inspect
 import fs
 from fs.opener import parse
 from PyQt5 import QtWidgets, QtCore
@@ -35,7 +37,7 @@ from PyQt5.QtGui import QIcon
 from PyQt5.QtCore import QSettings
 from fslib import ui_filepicker, __version__
 from fslib.utils import root_url, human_readable_info, match_extension,\
-    FOLDER_SPACES, FILES_SPACES, WidgetImage, get_extension_from_string, fs_url_exists
+    FOLDER_SPACES, FILES_SPACES, WidgetImage, get_extension_from_string, fs_url_exists, who_called_me
 from fslib.icons import icons
 
 
@@ -43,8 +45,10 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
     def __init__(self, parent=None, fs_url=u"~/", file_pattern=u'All Files (*)', title=u'FS File Picker',
                  default_filename=None, show_save_action=False, show_dirs_only=False):
         super(FilePicker, self).__init__(parent)
+        frame = inspect.stack()[1][0]
+        scope = who_called_me(frame)
         self.setupUi(self)
-        self.settings = QSettings("fs_filepicker")
+        self.settings = QSettings("fs_filepicker", scope)
         self.setWindowIcon(QIcon(icons('fs_logo.png', origin='fs')))
         self.file_icon = icons('text-x-generic.png')
         self.dir_icon = icons('folder.png')
@@ -115,8 +119,14 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
 
     def configure(self):
         if isinstance(self.file_pattern, list):
+            stored_file_type = self.settings.value("selected_file_pattern", self.file_pattern[0])
+            try:
+                index = self.file_pattern.index(stored_file_type)
+            except ValueError:
+                index = 0
             for pattern in self.file_pattern:
                 self.ui_FileType.addItem(pattern)
+            self.ui_FileType.setCurrentIndex(index)
         else:
             self.ui_FileType.addItems([self.file_pattern])
         if self.default_filename is not None:
@@ -184,7 +194,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             if fs_url_exists(fs_url):
                 self.ui_fs_serverlist.setVisible(True)
                 self.ui_fs_serverlist.addItem(fs_url)
-                self.save_fs_urls_settings()
+                self.save_settings()
             else:
                 msg = u'"%s" Url not valid' % fs_url
                 QErrorMessage(self).showMessage(msg)
@@ -207,7 +217,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             for item in self.settings.value("fs_urls"):
                 if item != url:
                     self.ui_fs_serverlist.addItem(item)
-            self.save_fs_urls_settings()
+            self.save_settings()
 
     def select_fs(self):
         """
@@ -376,6 +386,10 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                 if "folder" in self.wparm.img:
                     self.directory_history.append(list(self.wparm.value.keys())[0])
                     self.browse_folder(subdir=list(self.wparm.value.keys())[0])
+                    self.selection_name()
+                if "text" in self.wparm.img:
+                    self.ui_SelectedName.setText(self.wparm.text)
+                    self.action()
         except AttributeError:
             pass
 
@@ -499,6 +513,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         Action on Open / Save button
         """
         if self.show_save_action:
+            self.save_settings()
             self.filename = self.ui_SelectedName.text()
             if self.filename == u"":
                 return
@@ -535,11 +550,13 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             else:
                 self.close()
 
-    def save_fs_urls_settings(self):
+    def save_settings(self):
         items = []
         for index in xrange(self.ui_fs_serverlist.count()):
             items.append(self.ui_fs_serverlist.item(index).text())
         self.settings.setValue('fs_urls', items)
+        selected_file_pattern = self.ui_FileType.currentText()
+        self.settings.setValue("selected_file_pattern", selected_file_pattern)
         self.settings.sync()
 
 
@@ -575,7 +592,7 @@ def fs_filepicker(parent=None, fs_url=u'~/', file_pattern=u'All Files (*)', titl
         if dirname.startswith(fp.active_url):
             filename = u"{}{}".format(active_url, fp.filename)
         else:
-            filename = fs.path.combine(u"{}{}".format(active_url, dirname), fp.filename)
+            filename = os.path.abspath(fs.path.combine(u"{}{}".format(active_url, dirname), fp.filename))
     return filename, fp.selected_file_pattern[0]
 
 
